pub trait AsyncMutex<F: SyslogFormatter, D: AsyncSyslogDestination, DS: AsyncSyslogApi<F, D>> {
type MutxGuard<'mux>: AsyncMutexGuard<'mux, F, D, DS>
where Self: 'mux;
// Required methods
fn a_new(v: DS) -> Self;
async fn a_lock<'mux>(&'mux self) -> Self::MutxGuard<'mux>;
}Expand description
A trait which generalize the mutex from the std lib’s of multiple async executors. The trait should be implemented on the mutex direclty.
Required Associated Types
Sourcetype MutxGuard<'mux>: AsyncMutexGuard<'mux, F, D, DS>
where
Self: 'mux
type MutxGuard<'mux>: AsyncMutexGuard<'mux, F, D, DS> where Self: 'mux
A mutex guard type.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".