AsyncMutexGuard

Trait AsyncMutexGuard 

pub trait AsyncMutexGuard<'mux, F: SyslogFormatter, D: AsyncSyslogDestination, DS: AsyncSyslogApi<F, D>> {
    // Required methods
    fn guard(&self) -> &DS;
    fn guard_mut(&mut self) -> &mut DS;
}
A trait which generalize the mutex guarding emited by the mutex from various async executors.

Required Methods

fn guard(&self) -> &DS

Returns the reference to the inner type of the mutex guard.

fn guard_mut(&mut self) -> &mut DS

Returns the mutable reference to the inner type of the mutex guard.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'mux, F: SyslogFormatter + Send, D: AsyncSyslogDestination, IO: AsyncSyslogInternalIO> AsyncMutexGuard<'mux, F, D, AsyncSyslogInternal<F, D, IO>> for MutexGuard<'mux, AsyncSyslogInternal<F, D, IO>>

Source

fn guard(&self) -> &AsyncSyslogInternal<F, D, IO>

Source

fn guard_mut(&mut self) -> &mut AsyncSyslogInternal<F, D, IO>

Implementors