pub struct SyStream<'t, PRI, D, F, S>{ /* private fields */ }Expand description
A struct which is created when user attempts to create a streamable instance, i.e which can be used in write!.
Generics
PRI - a SyStreamPri which are:
SyStreamPriErr, SyStreamPriDebug, SyStreamPriAlert, SyStreamPriCrit, SyStreamPriEmerg, SyStreamPriInfo, SyStreamPriNotice, SyStreamPriWarning
Example
ⓘ
let log =
SingleSyslog::openlog(
Some("test1"),
LogStat::LOG_CONS | LogStat::LOG_NDELAY | LogStat::LOG_PID,
LogFacility::LOG_DAEMON,
SyslogLocal::new()
).unwrap();
write!(log.get_stream::<SyStreamPriDebug>(), "test stream singlesyslog {}", i).unwrap();Trait Implementations
Sourceimpl<'t, PRI: SyStreamPri, D: SyslogDestination, F: SyslogFormatter, S: SyStreamSyslogApi<F, D>> Write for SyStream<'t, PRI, D, F, S>
impl<'t, PRI: SyStreamPri, D: SyslogDestination, F: SyslogFormatter, S: SyStreamSyslogApi<F, D>> Write for SyStream<'t, PRI, D, F, S>
Sourceimpl<'t, PRI: SyStreamPri, D: SyslogDestination, F: SyslogFormatter, S: SyStreamSyslogApi<F, D>> Write for SyStream<'t, PRI, D, F, S>
impl<'t, PRI: SyStreamPri, D: SyslogDestination, F: SyslogFormatter, S: SyStreamSyslogApi<F, D>> Write for SyStream<'t, PRI, D, F, S>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
write_all_vectored)Attempts to write multiple buffers into this writer. Read more