pub trait SyStreamApi<'stream, F: SyslogFormatter, D: SyslogDestination, S: SyslogApi<F, D>> {
// Required method
fn stream(&'stream self, pri: Priority) -> SyStream<'stream, D, F, S>;
}Expand description
A standart trait which provides the access to the instance which implements std::fmt::Write.
The syslog requres the Priority of the message to be specified. The Write does not
allow to provide additional arguments. For this reason, a function stream borrows the
current syslog instance and stores the Priority which will be used later.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".