pub trait SyslogQueueChanSnd<F: SyslogFormatter, D: SyslogDestination, S: SyslogQueueChannel<F, D>>: Debug + Clone {
// Required method
fn q_send_blocking(&self, msg: SyCmd<F, D, S>) -> SyRes<()>;
// Provided method
async fn q_send(&self, _msg: SyCmd<F, D, S>) -> SyRes<()> { ... }
}Expand description
A trait which should be implemented by the channel provider which forms a command queue. This trait provides both or either the blocking send interface.
Required Methods
Sourcefn q_send_blocking(&self, msg: SyCmd<F, D, S>) -> SyRes<()>
fn q_send_blocking(&self, msg: SyCmd<F, D, S>) -> SyRes<()>
Sends the message over the channel in blocking mode.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".