SyslogQueueOneChanRcv

Trait SyslogQueueOneChanRcv 

pub trait SyslogQueueOneChanRcv<C> {
    // Required method
    fn recv_once_blocking(self) -> SyRes<C>;

    // Provided method
    async fn recv_once(self) -> SyRes<C>
       where Self: Sized { ... }
}
A trait which should be implemented by the channel provider which forms a command queue. This trait provides a Oneshot channel a receive interface for both sync and async modes.

Required Methods

fn recv_once_blocking(self) -> SyRes<C>

Receives once from the channel in sync mode.

Provided Methods

async fn recv_once(self) -> SyRes<C>
where Self: Sized,

Receives once from the channel in async mode. By default, it returns error if not implemented.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<C> SyslogQueueOneChanRcv<C> for Receiver<C>

Source

fn recv_once_blocking(self) -> SyRes<C>

Source

async fn recv_once(self) -> SyRes<C>
where Self: Sized,

Implementors